@@ -225,7 +225,9 @@ MainForm::MainForm ( QWidget *pParent )
 	: QMainWindow(pParent)
 {
 	m_ui.setupUi(this);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 1, 0)
+	QMainWindow::setWindowIcon(QIcon(":/images/qsampler.png"));
+#endif
 	// Pseudo-singleton reference setup.
 	g_pMainForm = this;
 
