@@ -1,7 +1,7 @@
 // qsamplerOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2004-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2022, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007,2008,2015 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -54,8 +54,12 @@ public:
 
 	// Command line arguments parser.
 	bool parse_args(const QStringList& args);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+	void show_error(const QString& msg);
+#else
 	// Command line usage helper.
 	void print_usage(const QString& arg0);
+#endif
 
 	// Startup supplied session file.
 	QString sSessionFile;
